@@ -72,9 +72,15 @@ class CsvConverter(RasaConverter):
                         "Check if you have given the labels in first column and texts in second column. "
                         "Download the sample file to understand the right file format"
                     )
-        if dataset[dataset.columns[1]].isna().any().any():
+        if (
+            not self.ignore_missing_examples
+            and dataset[dataset.columns[1]].isna().any().any()
+        ):
             raise NLUValidationError("Found missing Text in your csv data")
-        if not self.ignore_missing_examples and dataset.isna().any().any():
+        if (
+            not self.ignore_missing_examples
+            and dataset[dataset.columns[0]].isna().any().any()
+        ):
             raise NLUValidationError("Found missing label data in your csv")
 
     @staticmethod
@@ -99,6 +105,8 @@ class CsvConverter(RasaConverter):
         :return: training data in the Neuralspace format
         """
         nlu_data = []
+        if self.ignore_missing_examples:
+            dataset.dropna(inplace=True)
         self.__validate_nlu_file(dataset)
         labels = dataset[dataset.columns[0]]
         texts = dataset[dataset.columns[1]]
