@@ -1,18 +1,11 @@
-import yaml
-
-from neuralspace.transcription.constants import (
-    DOMAIN,
-    LANGUAGE_MODEL_MAP_PATH,
-    SAMPLE_RATE,
-    SUBURL,
-)
+from neuralspace.transcription.constants import DOMAIN, SAMPLE_RATE, SUBURL
+from neuralspace.transcription.language_map import LANGUAGE_MAP
 
 
 def get_sample_rate_and_suburl_from_language(language: str, specialization: str):
     sub_url = None
     sample_rate = None
-    with open(LANGUAGE_MODEL_MAP_PATH) as f:
-        model_map = yaml.safe_load(f)
+    model_map = LANGUAGE_MAP
     language_models = model_map.get(language, None)
     for model in language_models:
         if model[DOMAIN] == specialization:
